@@ -12,7 +12,7 @@ backtransform <- function(x, transform_post) {
 
     checkmate::assert_data_frame(x)
     checkmate::assert_function(transform_post)
-    cols <- intersect(colnames(x), c("comparison", "marginalmean", "predicted", "estimate", "conf.low", "conf.high"))
+    cols <- intersect(colnames(x), c("estimate", "conf.low", "conf.high"))
     draws <- attr(x, "posterior_draws")
 
     if (!is.null(draws)) {
