@@ -1,35 +1,23 @@
-#' Contrasts Between Adjusted Predictions
+#' Comparisons Between Predictions Made With Different Regressor Values
 #'
-#' Difference, ratio, or function of adjusted predictions, calculated for
-#' meaningfully different predictor values. The `tidy()` and `summary()`
-#' functions can be used to aggregate and summarize the output of
-#' `comparisons()`. To learn more, read the contrasts vignette, visit the
-#' package website, or scroll down this page for a full list of vignettes:
-#' * <https://vincentarelbundock.github.io/marginaleffects/articles/contrasts.html>
+#' @description
+#' Predict the outcome variable at different regressor values (e.g., college
+#' graduates vs. others), and compare those predictions by computing a difference,
+#' ratio, or some other function. `comparisons()` can return many quantities of
+#' interest, such as contrasts, differences, risk ratios, changes in log odds,
+#' slopes, elasticities, etc.
+#' 
+#' * `comparisons()`: unit-level (conditional) estimates.
+#' * `avg_comparisons()`: average (marginal) estimates.
+#' 
+#' The `newdata` argument and the `datagrid()` function can be used to control where statistics are evaluated in the predictor space: "at observed values", "at the mean", "at representative values", etc.
+#' 
+#' See the comparisons vignette and package website for worked examples and case studies:
+#' 
+#' * <https://vincentarelbundock.github.io/marginaleffects/articles/comparisons.html>
 #' * <https://vincentarelbundock.github.io/marginaleffects/>
 #'
-#' @section Vignettes and documentation:
-#'
-#' ```{r child = "vignettes/toc.Rmd"}
-#' ```
-#'
-#' @details
-#' A "contrast" is a difference, ratio of function of adjusted predictions,
-#' calculated for meaningfully different predictor values (e.g., College
-#' graduates vs. Others). Uncertainty estimates are computed using the delta
-#' method.
-#'
-#' The `newdata` argument can be used to control the kind of contrasts to report:
-#'
-#' * Average Contrasts
-#' * Adjusted Risk Ratios
-#' * Adjusted Risk Differences
-#' * Group-Average Contrasts
-#' * Contrasts at the Mean
-#' * Contrasts at User-Specified values (aka Contrasts at Representative values, MER).
-#' * Custom contrasts using arbitrary functions
-#'
-#' @inheritParams marginaleffects
+#' @inheritParams slopes
 #' @inheritParams predictions
 #' @param variables `NULL`, character vector, or named list. The subset of variables for which to compute contrasts.
 #' * `NULL`: compute contrasts for all the variables in the model object (can be slow).
@@ -75,7 +63,9 @@
 #' * function: accept two equal-length numeric vectors of adjusted predictions (`hi` and `lo`) and returns a vector of contrasts of the same length, or a unique numeric value.
 #'   - See the Transformations section below for examples of valid functions.
 #' @param transform_post string or function. Transformation applied to unit-level estimates and confidence intervals just before the function returns results. Functions must accept a vector and return a vector of the same length. Support string shortcuts: "exp", "ln"
-#' @param by Compute group-wise average estimates. Valid inputs:
+#' @param by Aggregate unit-level estimates (aka, marginalize, average over). Valid inputs:
+#'   - `FALSE`: return the original unit-level estimates.
+#'   - `TRUE`: aggregate estimates for each term.
 #'   - Character vector of column names in `newdata` or in the data frame produced by calling the function without the `by` argument.
 #'   - Data frame with a `by` column of group labels, and merging columns shared by `newdata` or the data frame produced by calling the same function without the `by` argument.
 #'   - See examples below.
@@ -84,24 +74,24 @@
 #' * `TRUE`: Contrasts represent the changes in adjusted predictions when all the predictors specified in the `variables` argument are manipulated simultaneously (a "cross-contrast").
 #' @template model_specific_arguments
 #' @template transform_pre_functions
+#' @template bayesian
 #'
 #' @examples
 #'
 #' library(marginaleffects)
-#' library(magrittr)
 #'
 #' # Linear model
 #' tmp <- mtcars
 #' tmp$am <- as.logical(tmp$am)
 #' mod <- lm(mpg ~ am + factor(cyl), tmp)
-#' comparisons(mod, variables = list(cyl = "reference")) %>% tidy()
-#' comparisons(mod, variables = list(cyl = "sequential")) %>% tidy()
-#' comparisons(mod, variables = list(cyl = "pairwise")) %>% tidy()
+#' comparisons(mod, variables = list(cyl = "reference")) |> tidy()
+#' comparisons(mod, variables = list(cyl = "sequential")) |> tidy()
+#' comparisons(mod, variables = list(cyl = "pairwise")) |> tidy()
 #'
 #' # GLM with different scale types
 #' mod <- glm(am ~ factor(gear), data = mtcars)
-#' comparisons(mod, type = "response") %>% tidy()
-#' comparisons(mod, type = "link") %>% tidy()
+#' comparisons(mod, type = "response") |> tidy()
+#' comparisons(mod, type = "link") |> tidy()
 #'
 #' # Contrasts at the mean
 #' comparisons(mod, newdata = "mean")
@@ -119,37 +109,36 @@
 #'
 #' # Numeric contrasts
 #' mod <- lm(mpg ~ hp, data = mtcars)
-#' comparisons(mod, variables = list(hp = 1)) %>% tidy()
-#' comparisons(mod, variables = list(hp = 5)) %>% tidy()
-#' comparisons(mod, variables = list(hp = c(90, 100))) %>% tidy()
-#' comparisons(mod, variables = list(hp = "iqr")) %>% tidy()
-#' comparisons(mod, variables = list(hp = "sd")) %>% tidy()
-#' comparisons(mod, variables = list(hp = "minmax")) %>% tidy()
+#' comparisons(mod, variables = list(hp = 1)) |> tidy()
+#' comparisons(mod, variables = list(hp = 5)) |> tidy()
+#' comparisons(mod, variables = list(hp = c(90, 100))) |> tidy()
+#' comparisons(mod, variables = list(hp = "iqr")) |> tidy()
+#' comparisons(mod, variables = list(hp = "sd")) |> tidy()
+#' comparisons(mod, variables = list(hp = "minmax")) |> tidy()
 #'
 #' # using a function to specify a custom difference in one regressor
 #' dat <- mtcars
 #' dat$new_hp <- 49 * (dat$hp - min(dat$hp)) / (max(dat$hp) - min(dat$hp)) + 1
 #' modlog <- lm(mpg ~ log(new_hp) + factor(cyl), data = dat)
 #' fdiff <- \(x) data.frame(x, x + 10)
-#' comparisons(modlog, variables = list(new_hp = fdiff)) %>% summary()
+#' avg_comparisons(modlog, variables = list(new_hp = fdiff))
 #'
 #' # Adjusted Risk Ratio: see the contrasts vignette
 #' mod <- glm(vs ~ mpg, data = mtcars, family = binomial)
-#' cmp <- comparisons(mod, transform_pre = "lnratioavg")
-#' summary(cmp, transform_avg = exp)
+#' avg_comparisons(mod, transform_pre = "lnratioavg", transform_post = exp)
 #'
 #' # Adjusted Risk Ratio: Manual specification of the `transform_pre`
-#' cmp <- comparisons(mod, transform_pre = function(hi, lo) log(mean(hi) / mean(lo)))
-#' summary(cmp, transform_avg = exp)
+#' avg_comparisons(
+#'      mod,
+#'      transform_pre = function(hi, lo) log(mean(hi) / mean(lo)),
+#'      transform_post = exp)
 #
 #' # cross contrasts
 #' mod <- lm(mpg ~ factor(cyl) * factor(gear) + hp, data = mtcars)
-#' cmp <- comparisons(mod, variables = c("cyl", "gear"), cross = TRUE)
-#' summary(cmp)
+#' avg_comparisons(mod, variables = c("cyl", "gear"), cross = TRUE)
 #'
 #' # variable-specific contrasts
-#' cmp <- comparisons(mod, variables = list(gear = "sequential", hp = 10))
-#' summary(cmp)
+#' avg_comparisons(mod, variables = list(gear = "sequential", hp = 10))
 #'
 #' # hypothesis test: is the `hp` marginal effect at the mean equal to the `drat` marginal effect
 #' mod <- lm(mpg ~ wt + drat, data = mtcars)
@@ -184,8 +173,10 @@
 #'
 #' # `by` argument
 #' mod <- lm(mpg ~ hp * am * vs, data = mtcars)
-#' cmp <- comparisons(mod, variables = "hp", by = c("vs", "am"))
-#' summary(cmp)
+#' comparisons(mod, by = TRUE)
+#'
+#' mod <- lm(mpg ~ hp * am * vs, data = mtcars)
+#' avg_comparisons(mod, variables = "hp", by = c("vs", "am"))
 #'
 #' library(nnet)
 #' mod <- multinom(factor(gear) ~ mpg + am * vs, data = mtcars, trace = FALSE)
@@ -200,21 +191,24 @@ comparisons <- function(model,
                         variables = NULL,
                         type = NULL,
                         vcov = TRUE,
+                        by = FALSE,
                         conf_level = 0.95,
                         transform_pre = "difference",
                         transform_post = NULL,
                         cross = FALSE,
-                        by = NULL,
                         wts = NULL,
                         hypothesis = NULL,
+                        df = Inf,
                         eps = NULL,
                         ...) {
 
 
     dots <- list(...)
 
+    # required by stubcols later, but might be overwritten
+    bycols <- NULL
 
-    # marginaleffects()` **must** run its own sanity checks and hardcode valid arguments
+    # slopes()` **must** run its own sanity checks and hardcode valid arguments
     internal_call <- dots[["internal_call"]]
     if (!isTRUE(internal_call)) {
         # if `newdata` is a call to `datagrid`, `typical`, or `counterfactual`,
@@ -240,24 +234,16 @@ comparisons <- function(model,
         cross <- sanitize_cross(cross, variables, model)
         type <- sanitize_type(model = model, type = type, calling_function = "marginaleffects")
 
-    # internal call from `marginaleffects()`
+    # internal call from `slopes()`
     } else {
-        # not allowed in `marginaleffects()`
+        # not allowed in `slopes()`
         cross <- FALSE
     }
 
-    # bayesian models do not support `by` and "avg" in `transform_pre`
-    if (!is.null(by)) {
-        if (isTRUE(insight::model_info(model)$is_bayesian)) {
-            msg <- format_msg(
-            "The `by` argument of the `comparisons()` and `marginaleffects()` functions is not supported for bayesian models. Users can call the `posteriordraws()` function and compute the quantities manually.")
-            stop(msg, call. = FALSE)
-        }
-    }
-
     conf_level <- sanitize_conf_level(conf_level, ...)
     sanity_dots(model, ...)
-    checkmate::assert_numeric(eps, len = 1, lower = 1e-10, null.ok = TRUE)
+    checkmate::assert_number(eps, lower = 1e-10, null.ok = TRUE)
+    checkmate::assert_number(df, lower = 1)
 
     # transforms
     sanity_transform_pre(transform_pre)
@@ -265,7 +251,14 @@ comparisons <- function(model,
     if (is.function(transform_pre)) {
         transform_pre_label <- deparse(substitute(transform_pre))
     }
-    transform_post <- sanitize_transform_post(transform_post)
+    if (is.function(transform_post)) {
+        transform_post_label <- deparse(substitute(transform_post))
+        transform_post <- sanitize_transform_post(transform_post)
+        names(transform_post) <- transform_post_label
+    } else {
+        transform_post <- sanitize_transform_post(transform_post)
+        transform_post_label <- names(transform_post)
+    }
 
 
     # used by `marginaleffects` to hard-code preference
@@ -286,7 +279,12 @@ comparisons <- function(model,
     marginalmeans <- isTRUE(checkmate::check_choice(newdata, choices = "marginalmeans"))
 
     # before sanitize_variables
-    newdata <- sanitize_newdata(model = model, newdata = newdata, by = by)
+    modeldata <- get_modeldata(model)
+    newdata <- sanitize_newdata(
+        model = model,
+        newdata = newdata,
+        by = by,
+        modeldata = modeldata)
 
     # weights: before sanitize_variables
     sanity_wts(wts, newdata) # after sanity_newdata
@@ -307,46 +305,59 @@ comparisons <- function(model,
         contrast_factor = contrast_factor,
         transform_pre = transform_pre)
 
-    hypothesis <- sanitize_hypothesis(hypothesis, ...)
+    tmp <- sanitize_hypothesis(hypothesis, ...)
+    hypothesis <- tmp$hypothesis
+    hypothesis_null <- tmp$hypothesis_null
 
     # after sanitize_newdata
     sanity_by(by, newdata)
 
 
     # get dof before transforming the vcov arg
-    if (is.character(vcov) &&
-       # get_df() produces a weird warning on non lmerMod. We can skip them
-       # because get_vcov() will produce an informative error later.
-       inherits(model, "lmerMod") &&
-       (isTRUE(vcov == "satterthwaite") || isTRUE(vcov == "kenward-roger"))) {
-        df <- insight::find_response(model)
+    # get_df() produces a weird warning on non lmerMod. We can skip them
+    # because get_vcov() will produce an informative error later.
+    if (inherits(model, "lmerMod") && (isTRUE(hush(vcov %in% c("satterthwaite", "kenward-roger"))))) {
         # predict.lmerTest requires the DV
-        if (!df %in% colnames(newdata)) {
-            newdata[[df]] <- mean(insight::get_response(model))
+        dv <- insight::find_response(model)
+        if (!dv %in% colnames(newdata)) {
+            newdata[[dv]] <- mean(insight::get_response(model))
         }
+
+        if (!isTRUE(hush(is.infinite(df)))) {
+            insight::format_error('The `df` argument is not supported when `vcov` is "satterthwaite" or "kenward-roger".')
+        }
+
         # df_per_observation is an undocumented argument introduced in 0.18.4.7 to preserve backward incompatibility
-        dof <- insight::get_df(model, type = vcov, data = newdata, df_per_observation = TRUE)
-    } else {
-        if ("df" %in% names(dots)) {
-            dof <- dots[["df"]]
-        } else {
-            dof <- NULL
-        }
+        df <- insight::get_df(model, type = vcov, data = newdata, df_per_observation = TRUE)
     }
 
-    vcov_false <- isTRUE(vcov == FALSE)
+    vcov_false <- isFALSE(vcov)
     vcov.type <- get_vcov_label(vcov)
     vcov <- get_vcov(model, vcov = vcov, ...)
 
     predictors <- variables_list$conditional
 
+    ############### sanity checks are over
+
+    # Bootstrap
+    out <- inferences_dispatch(
+        FUN = comparisons,
+        model = model, newdata = newdata, vcov = vcov, variables = variables, type = type, by = by,
+        conf_level = conf_level,
+        transform_pre = transform_pre, transform_post = transform_post, wts = wts, hypothesis = hypothesis, eps = eps, ...)
+    if (!is.null(out)) {
+        return(out)
+    }
+
+
     # compute contrasts and standard errors
     args <- list(model = model,
                  newdata = newdata,
                  variables = predictors,
                  cross = cross,
                  marginalmeans = marginalmeans,
-                 eps = eps)
+                 eps = eps,
+                 modeldata = modeldata)
     args <- c(args, dots)
     contrast_data <- do.call("get_contrast_data", args)
 
@@ -401,7 +412,7 @@ comparisons <- function(model,
     }
 
     # merge original data back in
-    if (is.null(by) && "rowid" %in% colnames(mfx)) {
+    if ((is.null(by) || isFALSE(by)) && "rowid" %in% colnames(mfx)) {
         if ("rowid" %in% colnames(newdata)) {
             idx <- c("rowid", "rowidcf", "term", "contrast", "by", setdiff(colnames(contrast_data$original), colnames(mfx)))
             idx <- intersect(idx, colnames(contrast_data$original))
@@ -424,12 +435,11 @@ comparisons <- function(model,
     mfx <- get_ci(
         mfx,
         conf_level = conf_level,
-        # sometimes get_predicted fails on SE but succeeds on CI (e.g., betareg)
-        df = dof,
-        overwrite = FALSE,
+        df = df,
         draws = draws,
-        estimate = "comparison")
-        
+        estimate = "estimate",
+        null_hypothesis = hypothesis_null,
+        model = model)
 
 
     # group id: useful for merging, only if it's an internal call and not user-initiated
@@ -439,17 +449,26 @@ comparisons <- function(model,
 
 
     # clean columns
-    stubcols <- c("rowid", "rowidcf", "type", "group", "term", "hypothesis",
-                  grep("^contrast", colnames(mfx), value = TRUE),
-                  "comparison", "std.error", "statistic", "p.value", "conf.low", "conf.high", "df",
-                  "predicted", "predicted_hi", "predicted_lo")
+    if (is.null(bycols) && isTRUE(checkmate::check_character(by))) {
+        bycols <- by
+    }
+    stubcols <- c(
+        "rowid", "rowidcf", "type", "group", "term", "hypothesis", "by",
+        grep("^contrast", colnames(mfx), value = TRUE),
+        bycols,
+        "estimate", "std.error", "statistic", "p.value", "conf.low",
+        "conf.high", "df", "predicted", "predicted_hi", "predicted_lo")
     cols <- intersect(stubcols, colnames(mfx))
     cols <- unique(c(cols, colnames(mfx)))
     mfx <- mfx[, ..cols, drop = FALSE]
+    mfx <- sort_columns(mfx, stubcols)
 
     # bayesian draws
     attr(mfx, "posterior_draws") <- draws
 
+    # equivalence tests
+    mfx <- equivalence(mfx, df = df, ...)
+
     # after draws attribute
     mfx <- backtransform(mfx, transform_post)
 
@@ -471,9 +490,9 @@ comparisons <- function(model,
         setDF(out)
     }
 
-    out <- set_attributes(
+    out <- set_marginaleffects_attributes(
         out,
-        get_attributes(newdata, include_regex = "^newdata"))
+        get_marginaleffects_attributes(newdata, include_regex = "^newdata"))
     attr(out, "model") <- model
     attr(out, "type") <- type
     attr(out, "model_type") <- class(model)[1]
@@ -485,10 +504,12 @@ comparisons <- function(model,
     attr(out, "transform_pre") <- transform_pre
     attr(out, "transform_post") <- transform_post[[1]]
     attr(out, "transform_pre_label") <- transform_pre_label
-    attr(out, "transform_post_label") <- names(transform_post)[1]
+    attr(out, "transform_post_label") <- transform_post_label
     attr(out, "conf_level") <- conf_level
     attr(out, "by") <- by
     attr(out, "call") <- match.call()
+    # save newdata for use in recall()
+    attr(out, "newdata") <- newdata
 
     if (inherits(model, "brmsfit")) {
         insight::check_if_installed("brms")
@@ -504,3 +525,76 @@ comparisons <- function(model,
     class(out) <- c("comparisons", class(out))
     return(out)
 }
+
+
+#' Average comparisons
+#' @describeIn comparisons Average comparisons
+#' @export
+#'
+avg_comparisons <- function(model,
+                            newdata = NULL,
+                            variables = NULL,
+                            type = NULL,
+                            vcov = TRUE,
+                            by = TRUE,
+                            conf_level = 0.95,
+                            transform_pre = "difference",
+                            transform_post = NULL,
+                            cross = FALSE,
+                            wts = NULL,
+                            hypothesis = NULL,
+                            df = Inf,
+                            eps = NULL,
+                            ...) {
+
+    # order of the first few paragraphs is important
+    # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
+    scall <- substitute(newdata)
+    if (is.call(scall)) {
+        lcall <- as.list(scall)
+        fun_name <- as.character(scall)[1]
+        if (fun_name %in% c("datagrid", "datagridcf", "typical", "counterfactual")) {
+            if (!any(c("model", "newdata") %in% names(lcall))) {
+                lcall <- c(lcall, list("model" = model))
+                newdata <- eval.parent(as.call(lcall))
+            }
+        } else if (fun_name == "visualisation_matrix") {
+            if (!"x" %in% names(lcall)) {
+                lcall <- c(lcall, list("x" = get_modeldata))
+                newdata <- eval.parent(as.call(lcall))
+            }
+        }
+    }
+
+    # Bootstrap
+    out <- inferences_dispatch(
+        FUN = avg_comparisons,
+        model = model, newdata = newdata, vcov = vcov, variables = variables, type = type, by = by,
+        conf_level = conf_level,
+        transform_pre = transform_pre, transform_post = transform_post, wts = wts, hypothesis = hypothesis, eps = eps, ...)
+    if (!is.null(out)) {
+        return(out)
+    }
+
+    out <- comparisons(
+        model = model,
+        newdata = newdata,
+        variables = variables,
+        type = type,
+        vcov = vcov,
+        by = by,
+        conf_level = conf_level,
+        transform_pre = transform_pre,
+        transform_post = transform_post,
+        cross = cross,
+        wts = wts,
+        hypothesis = hypothesis,
+        df = df,
+        eps = eps,
+        ...)
+
+    # overwrite call because otherwise we get the symbosl sent to comparisons()
+    attr(out, "call") <- match.call()
+
+    return(out)
+}
\ No newline at end of file
