@@ -11,6 +11,7 @@ get_contrasts <- function(model,
                           hypothesis = NULL,
                           cross = FALSE,
                           verbose = TRUE,
+                          deltamethod = FALSE,
                           ...) {
 
     settings_init()
@@ -44,6 +45,7 @@ get_contrasts <- function(model,
         pred_hi <- pred_both[idx_hi, , drop = FALSE]
         attr(pred_lo, "posterior_draws") <- attr(pred_both, "posterior_draws")[idx_lo, , drop = FALSE]
         attr(pred_hi, "posterior_draws") <- attr(pred_both, "posterior_draws")[idx_hi, , drop = FALSE]
+
     } else {
         pred_lo <- myTryCatch(get_predict(
             model,
@@ -60,19 +62,39 @@ get_contrasts <- function(model,
             ...))[["value"]]
     }
 
-    pred_or <- myTryCatch(get_predict(
-        model,
-        type = type,
-        vcov = FALSE,
-        newdata = original,
-        ...))[["value"]]
+    # predict() takes up 2/3 of the wall time. This call is only useful when we
+    # compute elasticities, or for the main estimate, not for standard errors,
+    # so we probably save 1/3 of that 2/3.
+    elasticities <- c(
+        # "dydx", # useless and expensive
+        "eyex",
+        "eydx",
+        "dyex",
+        # "dydxavg", # useless and expensive
+        "eyexavg",
+        "eydxavg",
+        "dyexavg")
+    fun <- function(x) {
+        out <- checkmate::check_choice(x$transform_pre, choices = elasticities)
+        isTRUE(out)
+    }
+    tmp <- Filter(fun, variables)
+    if (!isTRUE(deltamethod) || length(tmp) > 0) {
+        pred_or <- myTryCatch(get_predict(
+            model,
+            type = type,
+            vcov = FALSE,
+            newdata = original,
+            ...))[["value"]]
+    } else {
+        pred_or <- NULL
+    }
 
     # lots of indexing later requires a data.table
     setDT(original)
 
-    if (!inherits(pred_hi, "data.frame") || !inherits(pred_lo, "data.frame") || !inherits(pred_or, "data.frame")) {
-        msg <- insight::format_message("Unable to compute predicted values with this model. You can try to supply a different dataset to the `newdata` argument. If this does not work, you can file a report on the Github Issue Tracker: https://github.com/vincentarelbundock/marginaleffects/issues")
-        stop(msg, call. = FALSE)
+    if (!inherits(pred_hi, "data.frame") || !inherits(pred_lo, "data.frame") || !inherits(pred_or, c("data.frame", "NULL"))) {
+        insight::format_error("Unable to compute predicted values with this model. You can try to supply a different dataset to the `newdata` argument. If this does not work, you can file a report on the Github Issue Tracker: https://github.com/vincentarelbundock/marginaleffects/issues")
     }
 
     # output data.frame
@@ -86,14 +108,15 @@ get_contrasts <- function(model,
     out[, "marginaleffects_eps" := NA_real_] # default (probably almost always overwritten)
     out[, "marginaleffects_wts_internal" := NA_real_] # default (probably almost always overwritten)
     mult <- nrow(out) / nrow(original)
+    regex <- "^term$|^group$|^contrast|^marginaleffects_eps$|^marginaleffects_wts_internal$"
     if (isTRUE(mult == 1)) {
-        for (v in grep("^term$|^contrast|^marginaleffects_eps$|^marginaleffects_wts_internal$", colnames(original), value = TRUE)) {
+        for (v in grep(regex, colnames(original), value = TRUE)) {
             out[, (v) := original[[v]]]
         }
 
     # group or multivariate outcomes
     } else if (isTRUE(mult > 1)) {
-        for (v in grep("^term$|^contrast|^marginaleffects_eps$|^marginaleffects_wts_internal$", colnames(original), value = TRUE)) {
+        for (v in grep(regex, colnames(original), value = TRUE)) {
             out[, (v) := rep(original[[v]], times = mult)]
         }
 
@@ -113,11 +136,24 @@ get_contrasts <- function(model,
         out[, "term" := "cross"]
     }
 
+
     # by
     if (isTRUE(checkmate::check_data_frame(by))) {
         bycols <- "by"
         setDT(by)
         tmp <- setdiff(intersect(colnames(out), colnames(by)), "by")
+
+        if (length(tmp) == 0) {
+            if (all(colnames(by) %in% c("by", colnames(newdata)))) {
+                nd <- c("rowid", setdiff(colnames(by), "by"))
+                nd <- newdata[, nd, drop = FALSE]
+                out <- merge(out, nd, by = "rowid")
+                tmp <- setdiff(intersect(colnames(out), colnames(by)), "by")
+            } else {
+                insight::format_error("The column in `by` must be present in `newdata`.")
+            }
+        }
+
         # harmonize column types
         for (v in colnames(by)) {
             if (isTRUE(is.character(out[[v]])) && isTRUE(is.numeric(by[[v]]))) {
@@ -128,6 +164,11 @@ get_contrasts <- function(model,
         }
         out[by, by := by, on = tmp]
         by <- "by"
+
+    } else if (isTRUE(checkmate::check_character(by))) {
+        regex <- "^term$|^contrast_?|^group$"
+        by <- c(by, grep(regex, colnames(out), value = TRUE))
+        by <- unique(by)
     }
 
     # transform_pre function could be different for different terms
@@ -138,15 +179,6 @@ get_contrasts <- function(model,
     # elasticity requires the original (properly aligned) predictor values
     # this will discard factor variables which are duplicated, so in principle
     # it should be the "correct" size
-    elasticities <- c(
-        "dydx",
-        "eyex",
-        "eydx",
-        "dyex",
-        "dydxavg",
-        "eyexavg",
-        "eydxavg",
-        "dyexavg")
     elasticities <- Filter(
         function(x) is.character(x$transform_pre) && x$transform_pre %in% elasticities,
         variables)
@@ -162,9 +194,11 @@ get_contrasts <- function(model,
                 idx1 <- c(v, "rowid", "rowidcf", "term", "type", "group", grep("^contrast", colnames(original), value = TRUE))
                 idx1 <- intersect(idx1, colnames(original))
                 idx1 <- original[, ..idx1]
-                idx2 <- merge(idx1, idx2)
+                setnames(idx1, old = v, new = "elast")
+                on_cols <- intersect(colnames(idx1), colnames(idx2))
+                idx2[idx1, elast := elast, on = on_cols]
             }
-            elasticities[[v]] <- idx2[[v]]
+            elasticities[[v]] <- idx2$elast
         }
     }
 
@@ -181,9 +215,14 @@ get_contrasts <- function(model,
         draws_or <- attr(pred_or, "posterior_draws")
     }
 
-    out[, predicted_lo := pred_lo[["predicted"]]]
-    out[, predicted_hi := pred_hi[["predicted"]]]
-    out[, predicted := pred_or[["predicted"]]]
+    out[, predicted_lo := pred_lo[["estimate"]]]
+    out[, predicted_hi := pred_hi[["estimate"]]]
+
+    if (!is.null(pred_or)) {
+        out[, predicted := pred_or[["estimate"]]]
+    } else {
+        out[, predicted := NA_real_]
+    }
 
     idx <- grep("^contrast|^group$|^term$|^type$|^transform_pre_idx$", colnames(out), value = TRUE)
 
@@ -198,11 +237,10 @@ get_contrasts <- function(model,
         if (length(tmp) > 1) {
             tmp <- subset(newdata, select = tmp)
             out <- merge(out, tmp, all.x = TRUE, sort = FALSE)
-            idx <- c(idx, by)
+            idx <- unique(c(idx, by))
         }
     }
 
-
     # we feed these columns to safefun(), even if they are useless for categoricals
     if (!"marginaleffects_eps" %in% colnames(out)) out[, "marginaleffects_eps" := NA]
     if (!"marginaleffects_wts_internal" %in% colnames(out))  out[, "marginaleffects_wts_internal" := NA]
@@ -248,13 +286,29 @@ get_contrasts <- function(model,
         return(con)
     }
 
+    # drop missing otherwise get_averages() fails when trying to take a simple mean
+    idx_na <- !is.na(out$predicted_lo)
+    out <- out[idx_na, , drop = FALSE]
+
     # bayesian
     if (!is.null(draws)) {
-        term_names <- unique(out$term)
+        # TODO: performance is probably terrrrrible here, but splitting is
+        # tricky because grouping rows are not always contiguous, and the order
+        # of rows is **extremely** important because draws don't have the
+        # indices that would allow us to align them back with `out`
+        draws <- draws[idx_na, , drop = FALSE]
+
+        if (isTRUE(checkmate::check_character(by, min.len = 1))) {
+            by_idx <- subset(out, select = intersect(by, colnames(out)))
+            by_idx <- apply(by_idx, 1, paste, collapse = "|")
+        } else {
+            by_idx <- out$term
+        }
+
         # loop over columns (draws) and term names because different terms could use different functions 
-        for (tn in term_names) {
+        for (tn in unique(by_idx)) {
             for (i in seq_len(ncol(draws))) {
-                idx <- out$term == tn
+                idx <- by_idx == tn
                 draws[idx, i] <- safefun(
                     hi = draws_hi[idx, i],
                     lo = draws_lo[idx, i],
@@ -266,6 +320,7 @@ get_contrasts <- function(model,
                     eps = out$marginaleffects_eps[idx])
             }
         }
+
         # function returns unique value
         idx <- !is.na(draws[, 1])
         draws <- draws[idx, , drop = FALSE]
@@ -280,13 +335,17 @@ get_contrasts <- function(model,
             out <- out[idx, , drop = FALSE]
         }
 
+        FUN_CENTER <- getOption("marginaleffects_posterior_center", default = stats::median)
+        out[, "estimate" := apply(draws, 1, FUN_CENTER)]
+
     # frequentist
     } else {
-        # We want to write the "comparison" column in-place because it safer
+        # We want to write the "estimate" column in-place because it safer
         # than group-merge; there were several bugs related to this in the past.
         # safefun() returns 1 value and NAs when the function retunrs a
         # singleton.
-        out[, "comparison" := safefun(
+        idx <- intersect(idx, colnames(out))
+        out[, "estimate" := safefun(
             hi = predicted_hi,
             lo = predicted_lo,
             y = predicted,
@@ -300,31 +359,32 @@ get_contrasts <- function(model,
         # if transform_pre returns a single value, then we padded with NA. That
         # also means we don't want `rowid` otherwise we will merge and have
         # useless duplicates.
-        if (any(is.na(out$comparison))) {
+        if (any(is.na(out$estimate))) {
             if (settings_equal("marginaleffects_safefun_return1", TRUE)) {
                 out[, "rowid" := NULL]
             }
         }
-        out <- out[!is.na(comparison)]
+        out <- out[!is.na(estimate)]
     }
 
 
     # averaging by groups
-    # if `by` is a vector, we have done the work already above
+    # sometimes this work is already done
     # if `by` is a column name, then we have merged-in a data frame earlier
-    if (identical(by, "by") && "by" %in% colnames(out)) {
+    if (nrow(out) > 1 && !(is.null(by) || isFALSE(by)) &&
+        any(grepl("^contrast[_]?", colnames(out))) &&
+        !any(grepl("^mean\\(", out$contrast))) {
         out <- get_by(
             out,
             draws = draws,
             newdata = newdata,
             by = by,
-            column = "comparison",
             verbose = verbose)
 
         draws <- attr(out, "posterior_draws")
     }
 
-    # issue #531: uncertainy estimates from get_predict() sometimes get retained, but they are not overwritten later by get_ci()
+    # issue #531: uncertainty estimates from get_predict() sometimes get retained, but they are not overwritten later by get_ci()
     # drop by reference for speed
     bad <- intersect(
         colnames(out),
@@ -337,7 +397,7 @@ get_contrasts <- function(model,
     attr(out, "posterior_draws") <- draws
 
     # hypothesis tests using the delta method
-    out <- get_hypothesis(out, hypothesis, column = "comparison", by = by)
+    out <- get_hypothesis(out, hypothesis, by = by)
 
     # reset settings
     settings_rm("marginaleffects_safefun_return1")
