@@ -1,10 +1,10 @@
 #' Get predicted values from a model object (internal function)
 #'
 #' @return A data.frame of predicted values with a number of rows equal to the
-#' number of rows in `newdata` and columns "rowid" and "predicted". A "group"
+#' number of rows in `newdata` and columns "rowid" and "estimate". A "group"
 #' column is added for multivariate models or models with categorical outcomes. 
 #' @rdname get_predict
-#' @inheritParams marginaleffects
+#' @inheritParams slopes
 #' @keywords internal
 #' @export
 get_predict <- function(model, newdata, vcov, conf_level, type, ...) {
@@ -28,7 +28,7 @@ get_predict.default <- function(model,
     dots <- list(...)
 
     # some predict methods raise warnings on unused arguments
-    unused <- c("normalize_dydx", "eps", "numDeriv_method", "internal_call", "contrast_numeric_slope", "contrast_numeric", "contrast_factor")
+    unused <- c("normalize_dydx", "eps", "numDeriv_method", "internal_call", "contrast_numeric_slope", "contrast_numeric", "contrast_factor", "draw")
     dots <- dots[setdiff(names(dots), unused)]
 
     # incompatible arguments
@@ -95,7 +95,7 @@ get_predict.default <- function(model,
             }
             colnames(out)[colnames(out) == "Response"] <- "group"
             colnames(out)[colnames(out) == "SE"] <- "std.error"
-            colnames(out)[colnames(out) == "Predicted"] <- "predicted"
+            colnames(out)[colnames(out) == "Predicted"] <- "estimate"
             colnames(out)[colnames(out) == "CI_low"] <- "conf.low"
             colnames(out)[colnames(out) == "CI_high"] <- "conf.high"
 
@@ -103,7 +103,7 @@ get_predict.default <- function(model,
                 out$rowid <- newdata$rowid
             }
 
-            out <- sort_columns(out, first = c("rowid", "group", "predicted"))
+            out <- sort_columns(out, first = c("rowid", "group", "estimate"))
             return(out)
         }
     }
@@ -114,6 +114,11 @@ get_predict.default <- function(model,
     dots[["type"]] <- type_base
     args <- c(list(model), dots)
 
+    # breaks {rms} models, and it is only supported by `insight::get_predicted`
+    if ("ci_method" %in% names(args)) {
+        args[["ci_method"]] <- NULL
+    }
+
     fun <- stats::predict
     pred <- suppressWarnings(do.call("fun", args))
 
@@ -136,10 +141,10 @@ get_predict.default <- function(model,
         # strip weird attributes added by some methods (e.g., predict.svyglm)
         if (length(pred) == nrow(newdata)) {
             if ("rowid" %in% colnames(newdata)) {
-                out <- data.table(predicted = as.numeric(pred),
+                out <- data.table(estimate = as.numeric(pred),
                                   rowid = newdata$rowid)
             } else {
-                out <- data.table(predicted = as.numeric(pred),
+                out <- data.table(estimate = as.numeric(pred),
                                   rowid = seq_len(length(pred)))
             }
         }
@@ -151,12 +156,12 @@ get_predict.default <- function(model,
             out <- data.table(
                 rowid = rep(newdata[["rowid"]], times = ncol(pred)),
                 group = rep(colnames(pred), each = nrow(pred)),
-                predicted = c(pred))
+                estimate = c(pred))
         } else {
             out <- data.table(
                 rowid = rep(seq_len(nrow(pred)), times = ncol(pred)),
                 group = rep(colnames(pred), each = nrow(pred)),
-                predicted = c(pred))
+                estimate = c(pred))
         }
     } else {
         stop(sprintf("Unable to extract predictions of type %s from a model of class %s. Please report this problem, along with reproducible code and data on Github: https://github.com/vincentarelbundock/marginaleffects/issues", type, class(model)[1]), call. = FALSE)
@@ -164,7 +169,7 @@ get_predict.default <- function(model,
 
     setDF(out)
 
-    out <- sort_columns(out, first = c("rowid", "group", "predicted"))
+    out <- sort_columns(out, first = c("rowid", "group", "estimate"))
 
     return(out)
 }
