@@ -8,6 +8,6 @@ get_predict.tobit1 <- function(model,
                                ...) {
 
     out <- stats::predict(model, what = type, newdata = newdata)
-    out <- data.frame(rowid = seq_len(length(out)), predicted = out)
+    out <- data.frame(rowid = seq_len(length(out)), estimate = out)
     return(out)
 }
