@@ -12,6 +12,7 @@ utils::globalVariables(c(
 "..idx",
 "..idx1",
 "..idx2",
+"elast",
 "..tmp",
 "..variables_grid",
 "..w",
@@ -26,6 +27,7 @@ utils::globalVariables(c(
 "draw",
 "dydx",
 "eps",
+"estimates",
 "estimate",
 "formatBicLL",
 "gn",
