@@ -15,9 +15,28 @@ sanitize_variables <- function(variables,
         checkmate::check_list(variables, names = "unique"),
         combine = "or")
 
+    # reserved keywords
+    tmp <- insight::find_variables(model, flatten = TRUE)
+    if (isTRUE(checkmate::check_character(tmp))) {
+        reserved_input <- tmp
+    } else if (isTRUE(checkmate::check_list(tmp))) {
+        reserved_input <- names(tmp)
+    } else {
+        reserved_input <- NULL
+    }
+    reserved <- c("rowid", "group", "term", "contrast", "estimate", "std.error", "statistic", "conf.low", "conf.high")
+    bad <- intersect(reserved_input, reserved)
+    if (length(bad) > 0) {
+        msg <- c(
+            "The following variable names are forbidden to avoid conflicts with the column names of the outputs produced by the `marginaleffects` package:",
+            sprintf("%s", paste(sprintf('"%s"', bad), collapse = ", ")),
+            "Please rename your variables before fitting the model or specify the `variables` argument.")
+        insight::format_error(msg)
+    }
+
     # data
     if (is.null(newdata)) {
-        newdata <- hush(insight::get_data(model))
+        newdata <- get_modeldata(model)
     }
 
     modeldata <- attr(newdata, "newdata_modeldata")
@@ -55,39 +74,34 @@ sanitize_variables <- function(variables,
         } else {
             predictors <- unlist(predictors, recursive = TRUE, use.names = FALSE)
         }
+
+        # response is not a predictor, but sometimes we catch it
+        dv <- hush(insight::find_response(model, combine = FALSE))
+        predictors <- unique(setdiff(predictors, dv))
     } else {
         predictors <- variables
     }
 
-    # variable classes: compute only once
-    variable_class <- attr(newdata, "newdata_variable_class")
-
     # character -> list
     if (isTRUE(checkmate::check_character(predictors))) {
 
-        # when users includes variables not in the model
-        bad <- setdiff(predictors, names(variable_class))
-        if (length(bad) > 0) {
-            msg <- "These elements should not appear in the `variables` argument: %s."
-            msg <- sprintf(msg, paste(bad, collapse = ", "))
-            insight::format_error(msg)
-        }
+        predictors <- setdiff(predictors, reserved)
 
         predictors_new <- list()
 
         for (v in predictors) {
 
-            if (isTRUE(variable_class[[v]] == "numeric")) {
+            if (get_variable_class(newdata, v, "numeric")) {
 
                 # binary variables: we take the difference by default
-                v_unique <- unique(modeldata[[v]])
-                if (all(v_unique %in% 0:1)) {
+                if (all(modeldata[[v]] %in% 0:1)) {
                     predictors_new[[v]] <- 0:1
 
                 } else if (calling_function == "comparisons") {
                     predictors_new[[v]] <- contrast_numeric
 
                 } else if (calling_function == "predictions") {
+                    v_unique <- unique(modeldata[[v]])
                     if (length(v_unique) < 6) {
                         predictors_new[[v]] <- v_unique
                     } else {
@@ -130,15 +144,6 @@ sanitize_variables <- function(variables,
     idx <- !grepl(":", names(predictors))
     predictors <- predictors[idx]
 
-    # reserved keywords
-    reserved <- intersect(
-        names(predictors),
-        c("rowid", "group", "term", "contrast", "estimate", "std.error", "statistic", "conf.low", "conf.high"))
-    if (isTRUE(length(reserved) > 0)) {
-        predictors <- predictors[!names(predictors) %in% reserved]
-        msg <- sprintf("The following variable names are forbidden to avoid conflicts with the column names of the outputs produced by the `marginaleffects` package: %s Please rename your variables before fitting the model or specify the `variables` argument.", paste(reserved, collapse = ", "))
-        insight::format_warning(msg)
-    }
 
     # matrix variables are not supported
     mc <- attr(newdata, "newdata_matrix_columns")
@@ -160,7 +165,7 @@ sanitize_variables <- function(variables,
 
         if (v %in% colnames(newdata)) {
 
-            if (identical(variable_class[[v]], "numeric")) {
+            if (get_variable_class(newdata, v, "numeric")) {
 
                 if (calling_function == "comparisons") {
 
@@ -216,7 +221,7 @@ sanitize_variables <- function(variables,
                     }
                 }
 
-            } else if (isTRUE(variable_class[[v]] %in% c("factor", "character"))) {
+            } else if (get_variable_class(newdata, v, "categorical")) {
 
                 if (calling_function == "comparisons") {
                     valid <- c("reference", "sequential", "pairwise", "all")
@@ -265,7 +270,7 @@ sanitize_variables <- function(variables,
     others <- c(others, w)
 
     # goals:
-    # allow multiple function types: marginaleffects() uses both difference and dydx
+    # allow multiple function types: slopes() uses both difference and dydx
     # when transform_pre is defined, use that if it works or turn back to defaults
     # predictors list elements: name, value, function, label
 
@@ -301,7 +306,7 @@ sanitize_variables <- function(variables,
     }
 
     for (v in names(predictors)) {
-        if (isTRUE(variable_class[[v]] == "numeric")) {
+        if (get_variable_class(newdata, v, "numeric") || get_variable_class(newdata, v, "binary")) {
             fun <- fun_numeric
             lab <- lab_numeric
         } else {
@@ -316,6 +321,13 @@ sanitize_variables <- function(variables,
             "transform_pre" = transform_pre)
     }
 
+    # can't take the slope of an outcome
+    dv <- hush(insight::find_response(model))
+    if (any(names(predictors) %in% dv)) {
+        insight::format_error("The outcome variable cannot be used in the `variables` argument.")
+    }
+
+
     # interaction: get_contrasts() assumes there is only one function when interaction=TRUE
     if (isTRUE(interaction)) {
         for (p in predictors) {
