@@ -1,19 +1,22 @@
 sanity_by <- function(by, newdata) {
     checkmate::assert(
+        checkmate::check_flag(by),
         checkmate::check_data_frame(by, min.cols = 1, min.rows = 1),
         checkmate::check_character(by, min.len = 1),
         checkmate::check_null(by))
 
-    known <- c("by", "group", "term", "rowid", "rowidcf", colnames(newdata))
+    known <- c("by", "group", "term", "rowid", "rowidcf", "type", "contrast", colnames(newdata))
 
-    if (inherits(by, "data.frame")) {
+    if (isTRUE(checkmate::check_flag(by))) {
+        flag <- FALSE
+    } else if (inherits(by, "data.frame")) {
         flag <- !all(colnames(by) %in% known) || !"by" %in% colnames(by)
     } else {
-        flag <- !all(by %in% known)
+        flag <- !all(by %in% known | grepl("^contrast_", by))
     }
 
     if (flag) {
-        bycols <- paste(setdiff(colnames(newdata), c("rowid", "rowidcf", "term")), collapse = ", ")
+        bycols <- paste(setdiff(colnames(newdata), c("rowid", "rowidcf", "term", "group", "type")), collapse = ", ")
         msg <- c(
             "The `by` argument must be either:", "",
             sprintf("1. Character vector in which each element is part of: %s", bycols),
