@@ -1,4 +1,5 @@
 source("helpers.R")
+using("marginaleffects")
 
 set.seed(1)
 n <- 10
@@ -13,11 +14,12 @@ yB <- -1 + 3 * xB + rnorm(n / 2, 0, 0.1)
 
 simdat <- data.frame(group_id = group_id, x = c(xA, xB), y = c(yA, yB))
 simdat$group_id <- as.factor(simdat$group_id)
+tmp <<- simdat
 
-model_additive <- lm(y ~ x + group_id, data = simdat)
-model_interaction <- lm(y ~ x * group_id, data = simdat)
+model_additive <- lm(y ~ x + group_id, data = tmp)
+model_interaction <- lm(y ~ x * group_id, data = tmp)
 
-simdat_doA <- simdat_doB <- simdat
+simdat_doA <- simdat_doB <- tmp
 simdat_doA$group_id <- "A"
 simdat_doB$group_id <- "B"
 
@@ -26,14 +28,11 @@ g1 <- mean(predict(model_additive, newdata = simdat_doB)) -
 g2 <- mean(predict(model_interaction, newdata = simdat_doB)) -
       mean(predict(model_interaction, newdata = simdat_doA))
 
-c1 <- comparisons(model_additive, variable = "group_id")
+c1 <- comparisons(model_additive, variable = "group_id", newdata = tmp)
 c1 <- tidy(c1)
 
-c2 <- comparisons(model_interaction, variable = "group_id")
+c2 <- comparisons(model_interaction, variable = "group_id", newdata = tmp)
 c2 <- tidy(c2)
 
 expect_equivalent(g1, c1$estimate)
-expect_equivalent(g2, c2$estimate)
-
-
-
+expect_equivalent(g2, c2$estimate)
\ No newline at end of file
