@@ -1,25 +1,27 @@
 source("helpers.R")
-requiet("afex")
-requiet("emmeans")
+using("marginaleffects")
+
+exit_if_not(requiet("afex"))
+exit_if_not(requiet("emmeans"))
 
 data(md_12.1, package = "afex")
 mod <- aov_ez("id", "rt", md_12.1, within = c("angle", "noise"))
 
 # no validity
-expect_marginaleffects(mod)
+expect_slopes(mod)
 pre <- predictions(mod)
 expect_inherits(pre, "predictions")
 cmp <- comparisons(mod)
 expect_inherits(cmp, "comparisons")
 
 # marginalmeans vs. emmeans
-mm <- marginalmeans(
+mm <- marginal_means(
     mod,
     variables = c("angle", "noise"),
     cross = FALSE)
 em1 <- data.frame(emmeans(mod, ~angle))
 em2 <- data.frame(emmeans(mod, ~noise))
-expect_equal(mm$marginalmean, c(em1$emmean, em2$emmean))
+expect_equal(mm$estimate, c(em1$emmean, em2$emmean))
 expect_equal(mm$std.error, c(em1$SE, em2$SE))
 
 # contrasts vs emmeans
@@ -29,7 +31,7 @@ cmp <- comparisons(mod,
 em <- emmeans(mod, ~angle)
 em <- contrast(em, method = "trt.vs.ctrl1")
 em <- data.frame(em)
-expect_equal(cmp$comparison, em$estimate)
+expect_equal(cmp$estimate, em$estimate)
 expect_equal(cmp$std.error, em$SE)
 
 # predictions vs emmeans
@@ -39,7 +41,7 @@ pre <- predictions(
                        noise = md_12.1$noise))
 emm <- emmeans(mod, c("noise", "angle"))
 emm <- data.frame(emm)
-expect_equivalent(pre$predicted, emm$emmean)
+expect_equivalent(pre$estimate, emm$emmean)
 expect_equivalent(pre$std.error, emm$SE)
 
 
@@ -50,6 +52,6 @@ mod <- suppressMessages(aov_car(
     data = obk.long, observed = "gender"))
 
 em <- data.frame(emmeans(mod, ~ phase))
-mm <- marginalmeans(mod, "phase")
-expect_equivalent(mm$marginalmean, em$emmean)
+mm <- marginal_means(mod, "phase")
+expect_equivalent(mm$estimate, em$emmean)
 expect_equivalent(mm$std.error, em$SE)
