@@ -1,5 +1,6 @@
 source("helpers.R")
-requiet("biglm")
+using("marginaleffects")
+exit_if_not(requiet("biglm"))
 
 N <- 1e4
 x1 <- rnorm(N)
@@ -20,8 +21,8 @@ t1 <- tidy(big_m)
 t2 <- tidy(small_m)
 expect_equivalent(t1$estimate, t2$estimate)
 
-big_m <- marginaleffects(big, type = "link", vcov = FALSE)
-small_m <- marginaleffects(small, type = "link", vcov = FALSE)
+big_m <- slopes(big, type = "link", vcov = FALSE)
+small_m <- slopes(small, type = "link", vcov = FALSE)
 t1 <- tidy(big_m)
 t2 <- tidy(small_m)
 expect_equivalent(t1$estimate, t2$estimate)
