@@ -1,8 +1,9 @@
-source("helpers.R", local = TRUE)
-if (ON_CRAN) exit_file("on cran")
-requiet("geepack")
-requiet("emmeans")
-requiet("broom")
+source("helpers.R")
+using("marginaleffects")
+
+exit_if_not(requiet("geepack"))
+exit_if_not(requiet("emmeans"))
+exit_if_not(requiet("broom"))
 
 # Stata does not replicate coefficients exactly:
 # xtset Pig Time
@@ -15,12 +16,12 @@ mf <- formula(Weight ~ Cu * (Time + I(Time^2) + I(Time^3)))
 model <- suppressWarnings(geeglm(mf,
 data = dietox, id = Pig,
 family = poisson("identity"), corstr = "ar1"))
-expect_marginaleffects(model)
+expect_slopes(model)
 # emmeans
-mfx <- marginaleffects(model, variables = "Time", newdata = datagrid(Time = 10, Cu = "Cu000"), type = "link")
+mfx <- slopes(model, variables = "Time", newdata = datagrid(Time = 10, Cu = "Cu000"), type = "link")
 em <- suppressMessages(emtrends(model, ~Time, var = "Time", at = list(Time = 10, Cu = "Cu000")))
 em <- tidy(em)
-expect_equivalent(mfx$dydx, em$Time.trend, tolerance = .001)
+expect_equivalent(mfx$estimate, em$Time.trend, tolerance = .001)
 expect_equivalent(mfx$std.error, em$std.error, tolerance = .01)
 
 
@@ -47,13 +48,13 @@ model <- suppressWarnings(geeglm(mf,
 
 em <- tidy(emmeans::emmeans(model, ~Cu, df = Inf, at = list(Time = 10)), type = "response")
 pr <- predictions(model, datagrid(Time = 10, Cu = unique))
-expect_equal(em$estimate, pr$predicted)
+expect_equal(em$estimate, pr$estimate)
 expect_equal(em$std.error, pr$std.error)
 
 # TODO: not clear where `emmeans` holds the Time variable
 # em <- emmeans::emmeans(model, ~Cu, type = "response", df = Inf)
 # em <- data.frame(em)
-# expect_equal(mm$marginalmean, em$emmean)
+# expect_equal(mm$estimate, em$emmean)
 # expect_equal(mm$conf.low, em$asymp.LCL)
 # expect_equal(mm$conf.high, em$asymp.UCL)
 
