@@ -1,18 +1,19 @@
-source("helpers.R", local = TRUE)
-if (ON_CRAN) exit_file("on cran")
-requiet("glmx")
-requiet("MASS")
-requiet("margins")
+source("helpers.R")
+using("marginaleffects")
+
+exit_if_not(requiet("glmx"))
+exit_if_not(requiet("MASS"))
+exit_if_not(requiet("margins"))
 
 # glmx: marginaleffects vs. margins
 d <- data.frame(x = runif(200, -1, 1))
 d$y <- rnbinom(200, mu = exp(0 + 3 * d$x), size = 1)
 model <- glmx(y ~ x, data = d, family = negative.binomial, 
           xlink = "log", xstart = 0)
-expect_marginaleffects(model)
+expect_slopes(model)
 # margins produces all zeros for se
 mar <- margins(model, unit_ses = TRUE)
-mfx <- marginaleffects(model)
+mfx <- slopes(model)
 expect_true(expect_margins(mfx, mar, se = FALSE, tolerance = .001))
 
 
