@@ -1,14 +1,15 @@
-source("helpers.R", local = TRUE)
-if (ON_CRAN) exit_file("on cran")
-requiet("robustbase")
-requiet("margins")
+source("helpers.R")
+using("marginaleffects")
+
+exit_if_not(requiet("robustbase"))
+exit_if_not(requiet("margins"))
 
 # lmrob vs. margins
 data(coleman, package = "robustbase")
 model <- lmrob(Y ~ ., data=coleman, setting = "KS2014")
-expect_marginaleffects(model, n_unique = 1)
+expect_slopes(model, n_unique = 1)
 mar <- margins::margins(model, unit_ses = TRUE)
-mfx <- marginaleffects(model)
+mfx <- slopes(model)
 expect_true(expect_margins(mar, mfx))
 
 # glmrob vs. margins
@@ -16,7 +17,7 @@ data(epilepsy, package = "robustbase")
 model <- glmrob(Ysum ~ Age10 + Base4*Trt, family = poisson,
                 data = epilepsy, method= "Mqle",
                 control = glmrobMqle.control(tcc= 1.2))
-expect_marginaleffects(model)
+expect_slopes(model)
 mar <- margins::margins(model, unit_ses = TRUE)
-mfx <- marginaleffects(model)
+mfx <- slopes(model)
 expect_true(expect_margins(mar, mfx))
