@@ -1,20 +1,21 @@
-source("helpers.R", local = TRUE)
-if (ON_CRAN) exit_file("on cran")
-requiet("sampleSelection")
+source("helpers.R")
+using("marginaleffects")
 
-data("Mroz87", package = "sampleSelection")
-Mroz87$kids  <- (Mroz87$kids5 + Mroz87$kids618 > 0)
-dat <<- Mroz87
+exit_if_not(requiet("sampleSelection"))
+
+dat <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/sampleSelection/Mroz87.csv")
+dat$kids <- dat$kids5 + dat$kids618 > 0
+dat <<- dat
 
 # heckit: se not supported yet
 mod <- heckit(lfp ~ age + I( age^2 ) + faminc + kids + educ,
               wage ~ exper + I( exper^2 ) + educ + city, 
               data = dat)
-mfx <- marginaleffects(mod)
+mfx <- slopes(mod)
 expect_inherits(mfx, "marginaleffects")
-mfx <- marginaleffects(mod, part = "selection", type = "link")
+mfx <- slopes(mod, part = "selection", type = "link")
 expect_inherits(mfx, "marginaleffects")
-mfx <- marginaleffects(mod, part = "outcome", type = "unconditional")
+mfx <- slopes(mod, part = "outcome", type = "unconditional")
 expect_inherits(mfx, "marginaleffects")
 expect_true(all(is.na(mfx$std.error)))
 
@@ -23,10 +24,9 @@ expect_true(all(is.na(mfx$std.error)))
 mod <- selection(lfp ~ age + I( age^2 ) + faminc + kids + educ,
                  wage ~ exper + I( exper^2 ) + educ + city, 
                  data = dat)
-mfx <- marginaleffects(mod)
+mfx <- slopes(mod)
 expect_inherits(mfx, "marginaleffects")
-mfx <- marginaleffects(mod, part = "selection", type = "link")
+mfx <- slopes(mod, part = "selection", type = "link")
 expect_inherits(mfx, "marginaleffects")
-mfx <- marginaleffects(mod, part = "outcome", type = "unconditional")
+mfx <- slopes(mod, part = "outcome", type = "unconditional")
 expect_inherits(mfx, "marginaleffects")
-
