@@ -1,6 +1,7 @@
-source("helpers.R", local = TRUE)
-if (ON_CRAN) exit_file("on cran")
-requiet("scam")
+source("helpers.R")
+using("marginaleffects")
+
+exit_if_not(requiet("scam"))
 
 # no validity
 set.seed(4)
@@ -12,5 +13,5 @@ f2 <- exp(4 * x2) / (1 + exp(4 * x2)) # monotone increasing smooth
 y <- f1 + f2 + rnorm(n) * .5
 dat <- data.frame(x1 = x1, x2 = x2, y = y)
 mod <- scam(y ~ s(x1, bs = "cr") + s(x2, bs = "mpi"), data = dat)
-suppressWarnings(expect_marginaleffects(mod))
+suppressWarnings(expect_slopes(mod))
 expect_predictions(predictions(mod))
