@@ -1,9 +1,10 @@
-source("helpers.R", local = TRUE)
-if (ON_CRAN) exit_file("on cran")
-requiet("margins")
-requiet("emmeans")
-requiet("broom")
-requiet("survey")
+source("helpers.R")
+using("marginaleffects")
+
+exit_if_not(requiet("margins"))
+exit_if_not(requiet("emmeans"))
+exit_if_not(requiet("broom"))
+exit_if_not(requiet("survey"))
 
 # survey: marginaleffects vs. margins vs. emtrends
 data("fpc", package = "survey")
@@ -16,13 +17,13 @@ svyd <- survey::svydesign(
     data = fpc,
     nest = TRUE)
 mod <- survey::svyglm(x ~ nh, design = svyd)
-res <- marginaleffects(mod)
+res <- slopes(mod)
 mar <- suppressMessages(data.frame(margins(mod, unit_ses = TRUE)))
-expect_equivalent(res$dydx, as.numeric(mar$dydx_nh))
+expect_equivalent(res$estimate, as.numeric(mar$dydx_nh))
 expect_equivalent(res$std.error, as.numeric(mar$SE_dydx_nh), tolerance = 0.0001)
 # emtrends
 em <- emtrends(mod, ~nh, "nh", at = list(nh = 4))
 em <- tidy(em)
-mfx <- marginaleffects(mod, type = "link", newdata = data.frame(nh = 4))
-expect_equivalent(mfx$dydx, em$nh.trend, tolerance = .001) # CRAN tolerance
+mfx <- slopes(mod, type = "link", newdata = data.frame(nh = 4))
+expect_equivalent(mfx$estimate, em$nh.trend, tolerance = .001) # CRAN tolerance
 expect_equivalent(mfx$std.error, em$std.error, tolerance = .001)
