@@ -1,15 +1,14 @@
 source("helpers.R")
-if (ON_CRAN) exit_file("on cran")
-if (ON_CI) exit_file("on ci")
-requiet("survival")
-requiet("emmeans")
-requiet("broom")
-
+using("marginaleffects")
 
+exit_if_not(!ON_CI)
+exit_if_not(requiet("survival"))
+exit_if_not(requiet("emmeans"))
+exit_if_not(requiet("broom"))
 
 # clogit 
-N  <- 100000
-ng <- 50000
+N  <- 10000
+ng <- 5000
 exd <- data.frame(
     g = rep(1:ng, each = N / ng),
     out = rep(0L:1L, N / 2),
@@ -18,9 +17,13 @@ mod <- clogit(
     out ~ x + strata(g),
     method = "exact",
     data = exd)
-expect_inherits(marginaleffects(mod, type = "lp"), "marginaleffects")
-expect_inherits(comparisons(mod, type = "lp"), "comparisons")
-expect_inherits(predictions(mod, type = "lp"), "predictions")
+
+mfx <- slopes(mod, type = "lp")
+expect_inherits(mfx, "marginaleffects")
+cmp <- comparisons(mod, type = "lp")
+expect_inherits(cmp, "comparisons")
+pre <- predictions(mod, type = "lp")
+expect_inherits(pre, "predictions")
 
 
 # coxph vs. Stata
@@ -32,16 +35,16 @@ test1 <<- data.frame(time = c(4, 3, 1, 1, 2, 2, 3),
 mod <- coxph(Surv(time, status) ~ x + strata(sex),
              data = test1,
              ties = "breslow")
-mfx <- merge(tidy(marginaleffects(mod, type = "lp")), stata)
-expect_marginaleffects(mod, type = "risk", n_unique = 4)
+mfx <- merge(tidy(slopes(mod, type = "lp")), stata)
+expect_slopes(mod, type = "risk", n_unique = 4)
 expect_equivalent(mfx$estimate, mfx$dydxstata)
 expect_equivalent(mfx$std.error, mfx$std.errorstata)
 
 # emtrends
 em <- emtrends(mod, ~x, "x", at = list(time = 4, status = 1, x = 0, sex = factor(0, levels = 0:1)))
 em <- tidy(em)
-mfx <- marginaleffects(mod, variables = "x", type = "lp")
-expect_equivalent(mfx$dydx[1], em$x.trend)
+mfx <- slopes(mod, variables = "x", type = "lp")
+expect_equivalent(mfx$estimate[1], em$x.trend)
 expect_equivalent(mfx$std.error[1], em$std.error)
 
 
@@ -52,7 +55,7 @@ test2 <<- data.frame(start = c(1, 2, 5, 2, 1, 7, 3, 4, 8, 8),
                      event = c(1, 1, 1, 1, 1, 1, 1, 0, 0, 0),
                      x = c(1, 0, 0, 1, 0, 1, 1, 1, 0, 0))
 mod <- coxph(Surv(start, stop, event) ~ x, test2)
-expect_marginaleffects(mod, type = "risk", n_unique = 2)
+expect_slopes(mod, type = "risk", n_unique = 2)
 
 
 
@@ -66,29 +69,29 @@ mod <- coxph(Surv(time, status) ~ x + strata(sex),
              ties = "breslow")
 p1 <- predictions(mod, type = "lp")
 p2 <- predictions(mod, type = "risk")
-expect_true(all(p1$predicted != p2$predicted))
+expect_true(all(p1$estimate != p2$estimate))
 
 
 
 # bugs stay dead: numeric vs factor strata
 #skip_if_not_installed("insight", minimum_version = "0.17.0")
 stata <- readRDS(testing_path("stata/stata.rds"))$survival_coxph_01
-test1 <<- data.frame(time = c(4, 3, 1, 1, 2, 2, 3),
+tmp1 <<- data.frame(time = c(4, 3, 1, 1, 2, 2, 3),
                      status = c(1, 1, 1, 0, 1, 1, 0),
                      x = c(0, 2, 1, 1, 1, 0, 0),
                      sex = factor(c(0, 0, 0, 0, 1, 1, 1)))
-test2 <<- data.frame(time = c(4, 3, 1, 1, 2, 2, 3),
+tmp2 <<- data.frame(time = c(4, 3, 1, 1, 2, 2, 3),
                      status = c(1, 1, 1, 0, 1, 1, 0),
                      x = c(0, 2, 1, 1, 1, 0, 0),
                      sex = c(0, 0, 0, 0, 1, 1, 1))
 mod1 <- coxph(Surv(time, status) ~ x + strata(sex),
-              data = test1,
+              data = tmp1,
               ties = "breslow")
 mod2 <- coxph(Surv(time, status) ~ x + strata(sex),
-              data = test2,
+              data = tmp2,
               ties = "breslow")
-mfx1 <- merge(tidy(marginaleffects(mod1, type = "lp")), stata)
-mfx2 <- merge(tidy(marginaleffects(mod2, type = "lp")), stata)
-expect_equivalent(mfx1$dydx, mfx2$dydx)
+mfx1 <- merge(tidy(slopes(mod1, type = "lp")), stata)
+mfx2 <- merge(tidy(slopes(mod2, type = "lp")), stata)
+expect_equivalent(mfx1$estimate, mfx2$estimate)
 
 
