@@ -1,10 +1,11 @@
 source("helpers.R")
-requiet("survey")
-requiet("MatchIt")
+using("marginaleffects")
+exit_if_not(requiet("survey"))
 
 # mtcars logit
-dat <- mtcars
-dat$weights <- dat$w <- 1:32
+tmp <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/datasets/mtcars.csv")
+tmp$weights <- tmp$w <- 1:32
+dat <<- tmp
 mod <- suppressWarnings(svyglm(
     am ~ mpg + cyl,
     design = svydesign(ids = ~1, weights = ~weights, data = dat),
@@ -16,15 +17,15 @@ p3 <- predictions(mod, wts = "w", newdata = dat)
 p4 <- predictions(mod, wts = dat$weights)
 expect_false(tidy(p1)$estimate == tidy(p2)$estimate)
 expect_false(tidy(p1)$std.error == tidy(p2)$std.error)
-expect_equal(tidy(p2), tidy(p3))
-expect_equal(tidy(p2), tidy(p4))
+expect_equivalent(tidy(p2), tidy(p3))
+expect_equivalent(tidy(p2), tidy(p4))
 
 
 # by supports weights
 p1 <- predictions(mod, wts = "weights", newdata = dat)
 p1 <- tidy(p1)
 expect_inherits(p1, "data.frame")
-m1 <- marginaleffects(mod, wts = "weights", newdata = dat, by = "cyl")
+m1 <- slopes(mod, wts = "weights", newdata = dat, by = "cyl")
 m1 <- tidy(m1)
 expect_inherits(m1, "data.frame")
 c1 <- comparisons(mod, wts = "weights", newdata = dat, by = "cyl")
@@ -33,42 +34,43 @@ expect_inherits(c1, "data.frame")
 
 
 # wts + transform_pre="avg"
-requiet("MatchIt")
-data("lalonde", package = "MatchIt")
 set.seed(100)
-lalonde$w <- rchisq(614, 2)
+k <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/MatchIt/lalonde.csv")
+k$w <- rchisq(614, 2)
 fit <- lm(re78 ~ treat * (age + educ + race + married + re74),
-          data = lalonde, weights = w)
+          data = k, weights = w)
 cmp1 <- comparisons(fit, variables = "treat", wts = "w")
-cmp2 <- comparisons(fit,variables = "treat", wts = "w", transform_pre = "differenceavg")
-expect_equivalent(tidy(cmp1)$estimate, weighted.mean(cmp1$comparison, lalonde$w))
-expect_equivalent(cmp2$comparison, weighted.mean(cmp1$comparison, lalonde$w))
-
-set.seed(1024)
-mod <- marginaleffects:::modelarchive_model("brms_numeric2")
-w <- runif(32)
-cmp1 <- comparisons(mod, transform_pre = "differenceavg")
-cmp2 <- comparisons(mod, wts = w, transform_pre = "differenceavg")
-cmp3 <- comparisons(mod, wts = w, transform_pre = "differenceavgwts")
-expect_true(all(cmp1$comparison != cmp2$comparison))
-expect_equivalent(cmp2$comparison, cmp3$comparison)
-
+cmp2 <- comparisons(fit, variables = "treat", wts = "w", transform_pre = "differenceavg")
+expect_equivalent(tidy(cmp1)$estimate, weighted.mean(cmp1$estimate, k$w))
+expect_equivalent(cmp2$estimate, weighted.mean(cmp1$estimate, k$w))
 
 
 # sanity check
 expect_error(comparisons(mod, wts = "junk"), pattern = "explicitly")
-expect_error(marginaleffects(mod, wts = "junk"), pattern = "explicitly")
+expect_error(slopes(mod, wts = "junk"), pattern = "explicitly")
 
 # vs. Stata (not clear what SE they use, so we give tolerance)
 mod <- suppressWarnings(svyglm(
     am ~ mpg,
     design = svydesign(ids = ~1, weights = ~weights, data = dat),
     family = binomial))
-stata <- c("estimate" = .0441066, "std.error" = .0061046)
-mfx <- marginaleffects(mod, wts = mod$prior.weights)
-mfx <- tidy(mfx)
-mfx <- unlist(mfx[, 3:4])
-expect_equivalent(mfx, stata, tolerance = 0.0002)
+tmp <- mod$prior.weights
+stata <- c(.0441066, .0061046)
+mfx <- slopes(mod, wts = tmp, by = "term")
+expect_equivalent(mfx$estimate[1], stata[1], tol = .01)
+expect_equivalent(mfx$std.error, stata[2], tolerance = 0.002)
+
+
+
+# brms
+set.seed(1024)
+mod <- marginaleffects:::modelarchive_model("brms_numeric2")
+w <- runif(32)
+cmp1 <- comparisons(mod, transform_pre = "differenceavg")
+cmp2 <- comparisons(mod, wts = w, transform_pre = "differenceavg")
+cmp3 <- comparisons(mod, wts = w, transform_pre = "differenceavgwts")
+expect_true(all(cmp1$estimate != cmp2$estimate))
+expect_equivalent(cmp2$estimate, cmp3$estimate)
 
 # . logit am mpg [pw=weights]
 #
@@ -107,3 +109,4 @@ expect_equivalent(mfx, stata, tolerance = 0.0002)
 # ------------------------------------------------------------------------------
 
 
+
